@@ -7,3 +7,6 @@ class ProductionConfig(Config):
 
     def authentication_host(self) -> str:
         return 'https://starmart.io'
+
+    def git_remote_host(self):
+        return 'https://gitlab.com/starmart/user-uploaded-mappers-and-models'
